@@ -24,6 +24,20 @@ if(isset($params['notification'])){
 if(isset($params['banned_template'])){
 $this->SetTemplate ('banned_template', $params['banned_template'], 'IPLock');
 }
+
+if(isset($params['email'])){
+	$this->SetPreference('email', $params['email']);
+	$emaillist = explode(',', $params['admin_email']);
+	$validemaillist = array();
+	foreach($emaillist as $email){
+		$email = str_replace(' ', '', $email);
+		if( eregi("^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$", $email) ){
+			$validemaillist[] = $email;
+		}
+	}
+	$admin_email = implode(', ', $validemaillist);
+	$this->SetPreference('admin_email', $admin_email);
+}
  
  
 $returnparams['active_tab'] = 'prefs';
