@@ -149,7 +149,7 @@ class IPFilter {
 	}
 	
 	
-	private static function addIP($ip, $ip_mode){
+	private static function addIP($ip, $ip_mode, $cause = 'admin'){
 		if (! self::checkIP ( $ip )) {
 			return IPFILTER_IP_ERROR;
 		} else {
@@ -164,6 +164,9 @@ class IPFilter {
 				$query = 'UPDATE '.cms_db_prefix().'module_iplock SET ip_mode=? WHERE ip_value =?';
 				$result = self::$db->Execute($query,array(IPFILTER_ALLOW,$ip));	
 			}
+			if($ip_mode == IPFILTER_DENY){
+				self::$iplock->SendEvent('UserBanned', array('ip' => $ip, 'cause' => $cause));
+			}
 			return IPFILTER_SUCCESS;
 		}
 	}
@@ -180,12 +183,12 @@ class IPFilter {
 		return self::addIP($ip, IPFILTER_ALLOW);
 	}
 	
-	public static function denyIP( $ip ) {
+	public static function denyIP( $ip , $cause = 'admin') {
 		if ( $ip == '127.0.0.1' ) {
 			return IPFILTER_NO_CHANGE;
 		}
 		else {
-			return self::addIP( $ip, IPFILTER_DENY );
+			return self::addIP( $ip, IPFILTER_DENY , $cause);
 		}
 	}
 	
@@ -296,8 +299,9 @@ else {
 		// If the user tried and failed to log in more than the number
 		// specified in prefs (max_conn / minute), we bann it's IP
 		if ($row['try_count'] > $max_conn_min){
-			self::denyIP($ip);
+			self::denyIP($ip, 'auto');
 			self::$iplock->SetPreference('new_banned_ip', 'not_verified');
+			self::$iplock->_AlertEmail($ip);
 			return IPFILTER_DENY;
 		}
 		$row['total_try_count']++;
