@@ -16,8 +16,11 @@ $this->RemovePreference('operating_process');
 $this->RemovePreference('max_conn_min');
 $this->RemovePreference('new_banned_ip');
 $this->RemovePreference('notification');
+$this->RemovePreference('email');
+$this->RemovePreference('admin_email');
 
 $this->RemoveEventHandler('Core', 'LoginPost');
+$this->RemoveEvent('UserBanned');
 
 $this->Audit(0, $this->GetName(), $this->Lang('uninstalled', $this->GetVersion()));
 
