@@ -30,4 +30,8 @@ switch($current_version){
 		$this->RemovePreference('IPLock_mode');
 		$this->SetPreference('new_banned_ip', 'verified');
 		$this->SetPreference('notification', 'display');
+	case '0.4':
+		$this->SetPreference('email', 'dontsend');
+		$this->SetPreference('admin_email', '');
+		$this->CreateEvent('UserBanned');
 }
\ No newline at end of file
